@@ -2,14 +2,13 @@ package File::pushd;
 use strict;
 use warnings;
 use Carp;
-use Exporter 'import';
 use File::Temp qw();
 use Path::Class;
-use base 'Path::Class::Dir';
+use base qw( Exporter Path::Class::Dir );
 
 BEGIN {
     use vars qw ($VERSION @EXPORT);
-    $VERSION     = "0.23";
+    $VERSION     = "0.24";
     @EXPORT      = qw (pushd tempd);
 }
 
